/******************************************************************************
* C Include: Generic                                                          *
*                                                                             *
* File:                                                                       *
*    generic.h                                                                *
*                                                                             *
* Description:                                                                *
*    Include file for the Generic functions.                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 01-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __GENERIC__
#define __GENERIC__

#include "config.h"

/*****************
* Generic macros *
*****************/
#define max(a,b)    (((a) > (b)) ? (a) : (b))
#define min(a,b)    (((a) < (b)) ? (a) : (b))

/*****************************
* Generic derived data types *
*****************************/
enum bool { False = FALSE, True = TRUE};
typedef enum bool BOOL;

typedef char* STRING;

/********************************
* Generic functions' prototypes *
********************************/
       void   *Allocate_Memory               (/* int    Size    */);

       void    Convert_String_to_Lower_Case  (/* STRING String  */);

       void    Convert_String_to_Upper_Case  (/* STRING String  */);

extern double  dtotal                        (/* double a[]     ,
						 int    n        */);

       void    Handle_Fatal_Error            (/* STRING Function,
						 STRING Message  */);

extern char   *remquotes                     (/* char   string[] */);

extern char   *strtrim                       (/* char   string[] */);

       STRING  Translate_Environment_Variable(/* STRING Variable */);

       void    Trim_Trailing_White_Space     (/* STRING String   */);


/******************************
* Generic include file page 2 *
******************************/

#endif
